pub struct MagnitudePruner { /* private fields */ }Expand description
Simple magnitude-based pruner.
Uses weight magnitude as importance and generates masks to achieve the target sparsity by pruning the smallest weights.
Implementations
Sourceimpl MagnitudePruner
impl MagnitudePruner
Sourcepub fn new() -> MagnitudePruner
pub fn new() -> MagnitudePruner
Create a new magnitude pruner with L2 norm.
Sourcepub fn l1() -> MagnitudePruner
pub fn l1() -> MagnitudePruner
Create a magnitude pruner with L1 norm.
Sourcepub fn l2() -> MagnitudePruner
pub fn l2() -> MagnitudePruner
Create a magnitude pruner with L2 norm.