pub struct ComputeGraph { /* private fields */ }Expand description
Computation graph with optimization support
Implementations
Sourceimpl ComputeGraph
impl ComputeGraph
Sourcepub fn add_constant(&mut self, data: Array1<f32>) -> NodeId
pub fn add_constant(&mut self, data: Array1<f32>) -> NodeId
Add a constant node to the graph
Sourcepub fn add_op(
&mut self,
op_type: OpType,
input_ids: Vec<NodeId>,
output_shape: Vec<usize>,
) -> NodeId
pub fn add_op( &mut self, op_type: OpType, input_ids: Vec<NodeId>, output_shape: Vec<usize>, ) -> NodeId
Add an operation node to the graph
Sourcepub fn mark_output(&mut self, node_id: NodeId)
pub fn mark_output(&mut self, node_id: NodeId)
Mark a node as an output of the graph
Sourcepub fn node_mut(&mut self, id: NodeId) -> &mut GraphNode
pub fn node_mut(&mut self, id: NodeId) -> &mut GraphNode
Get a mutable reference to a node by ID
Sourcepub fn active_node_count(&self) -> usize
pub fn active_node_count(&self) -> usize
Count non-removed nodes
Sourcepub fn output_ids(&self) -> &[NodeId] ⓘ
pub fn output_ids(&self) -> &[NodeId] ⓘ
Get output node IDs
Sourcepub fn topological_order(&self) -> Vec<NodeId> ⓘ
pub fn topological_order(&self) -> Vec<NodeId> ⓘ
Compute topological order of non-removed nodes
Sourcepub fn replace_uses(&mut self, old_id: NodeId, new_id: NodeId)
pub fn replace_uses(&mut self, old_id: NodeId, new_id: NodeId)
Replace all uses of old_id with new_id in the graph