pub struct BatutaClient { /* private fields */ }Expand description
Client for interacting with Batuta pricing and queue services.
Implementations
Sourceimpl BatutaClient
impl BatutaClient
Sourcepub fn with_url(url: impl Into<String>) -> Self
pub fn with_url(url: impl Into<String>) -> Self
Create a client connected to a Batuta instance.
Sourcepub fn with_timeout(self, timeout: Duration) -> Self
pub fn with_timeout(self, timeout: Duration) -> Self
Set connection timeout.
Sourcepub fn with_fallback(self, fallback: FallbackPricing) -> Self
pub fn with_fallback(self, fallback: FallbackPricing) -> Self
Set custom fallback pricing.
Sourcepub fn is_connected(&self) -> bool
pub fn is_connected(&self) -> bool
Check if connected to a live Batuta service.
Sourcepub fn get_hourly_rate(&self, gpu_type: &str) -> Result<GpuPricing, BatutaError>
pub fn get_hourly_rate(&self, gpu_type: &str) -> Result<GpuPricing, BatutaError>
Get hourly rate for a GPU type.
Returns live pricing from Batuta if available, otherwise fallback pricing.
Sourcepub fn get_queue_depth(&self, gpu_type: &str) -> Result<QueueState, BatutaError>
pub fn get_queue_depth(&self, gpu_type: &str) -> Result<QueueState, BatutaError>
Get current queue depth.
Returns queue state from Batuta if available, otherwise returns an optimistic default (no queue).
Sourcepub fn get_status(
&self,
gpu_type: &str,
) -> Result<(GpuPricing, QueueState), BatutaError>
pub fn get_status( &self, gpu_type: &str, ) -> Result<(GpuPricing, QueueState), BatutaError>
Get both pricing and queue state in one call.
Sourcepub fn estimate_cost(
&self,
gpu_type: &str,
hours: f64,
) -> Result<f64, BatutaError>
pub fn estimate_cost( &self, gpu_type: &str, hours: f64, ) -> Result<f64, BatutaError>
Estimate total cost for a job.
Sourcepub fn cheapest_gpu(&self, min_memory_gb: u32) -> Option<&GpuPricing>
pub fn cheapest_gpu(&self, min_memory_gb: u32) -> Option<&GpuPricing>
Get the cheapest GPU that meets memory requirements.