pub struct ClassifyTuner {
pub config: TuneConfig,
pub space: HyperparameterSpace,
pub leaderboard: Vec<TrialSummary>,
}Expand description
Orchestrates hyperparameter optimization for classification fine-tuning.
Coordinates:
- Searcher (TPE/Grid/Random) to suggest configs
- Scheduler (ASHA/Median/None) for early stopping
- ClassifyTrainer execution per trial
- Leaderboard ranking and persistence
Fields
config: TuneConfigTuning configuration.
space: HyperparameterSpaceSearch space.
leaderboard: Vec<TrialSummary>Completed trial summaries.
Implementations
Sourceimpl ClassifyTuner
impl ClassifyTuner
Sourcepub fn new(config: TuneConfig) -> Result<Self>
pub fn new(config: TuneConfig) -> Result<Self>
Create a new tuner with the default classification search space.
Sourcepub fn build_searcher(&self) -> Box<dyn TuneSearcher>
pub fn build_searcher(&self) -> Box<dyn TuneSearcher>
Create the appropriate searcher based on strategy.
Sourcepub fn build_scheduler(&self) -> Box<dyn TuneScheduler>
pub fn build_scheduler(&self) -> Box<dyn TuneScheduler>
Create the appropriate scheduler.
Sourcepub fn record_trial(&mut self, summary: TrialSummary)
pub fn record_trial(&mut self, summary: TrialSummary)
Record a completed trial result and update the leaderboard.
Sourcepub fn best_trial(&self) -> Option<&TrialSummary>
pub fn best_trial(&self) -> Option<&TrialSummary>
Get the best trial summary from the leaderboard.
Sourcepub fn into_result(self, total_time_ms: u64) -> TuneResult
pub fn into_result(self, total_time_ms: u64) -> TuneResult
Build the final TuneResult from collected trials.