build_launch_command

Function build_launch_command 

pub fn build_launch_command(
    node: &NodeConfig,
    model_path: &Path,
    data_path: &Path,
    checkpoint_dir: &Path,
    rank: u32,
    epochs: u32,
) -> String
Build a remote launch command for an adapter job on a node.

Returns the shell command that would be executed on the remote node to start training.