pub struct TraceStoragePolicy {
pub compression: CompressionAlgorithm,
pub retention_days: u32,
pub max_size_bytes: u64,
pub sample_rate: f64,
}Expand description
Trace storage configuration policy
Controls how experiment traces are stored, compressed, and retained.
Fields
compression: CompressionAlgorithmCompression algorithm to use for trace data
retention_days: u32Number of days to retain trace data (0 = indefinite)
max_size_bytes: u64Maximum storage size in bytes (0 = unlimited)
sample_rate: f64Sampling rate for trace collection (0.0-1.0) 1.0 = collect all traces, 0.5 = collect 50%, etc.
Implementations
Sourceimpl TraceStoragePolicy
impl TraceStoragePolicy
Sourcepub fn new(
compression: CompressionAlgorithm,
retention_days: u32,
max_size_bytes: u64,
sample_rate: f64,
) -> Self
pub fn new( compression: CompressionAlgorithm, retention_days: u32, max_size_bytes: u64, sample_rate: f64, ) -> Self
Create a new trace storage policy
Sourcepub fn development() -> Self
pub fn development() -> Self
Create a policy optimized for development (high detail, short retention)
Sourcepub fn production() -> Self
pub fn production() -> Self
Create a policy optimized for production (balanced)
Sourcepub fn should_sample(&self, trace_id: &str) -> bool
pub fn should_sample(&self, trace_id: &str) -> bool
Check if a trace should be sampled based on the sample rate
Uses a deterministic hash of the trace ID for consistent sampling.
Sourcepub fn estimate_compressed_size(&self, uncompressed_bytes: u64) -> u64
pub fn estimate_compressed_size(&self, uncompressed_bytes: u64) -> u64
Estimate the compressed size of data given uncompressed size
Sourcepub fn would_exceed_limit(
&self,
current_bytes: u64,
additional_bytes: u64,
) -> bool
pub fn would_exceed_limit( &self, current_bytes: u64, additional_bytes: u64, ) -> bool
Check if adding data would exceed the storage limit
Sourcepub fn is_indefinite_retention(&self) -> bool
pub fn is_indefinite_retention(&self) -> bool
Check if retention is indefinite
Sourcepub fn is_unlimited_storage(&self) -> bool
pub fn is_unlimited_storage(&self) -> bool
Check if storage is unlimited
Sourcepub fn sample_percentage(&self) -> f64
pub fn sample_percentage(&self) -> f64
Get the effective sample percentage (0-100)
Sourcepub fn validate(&self) -> Result<(), PolicyValidationError>
pub fn validate(&self) -> Result<(), PolicyValidationError>
Validate the policy configuration